var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { codeSampleGenerators } from './code-samples';
import { generateMediaTypeExample, generateSchemaExample } from './generateSchemaExample';
import { InteractiveSection } from './InteractiveSection';
import { getServersURL } from './OpenAPIServerURL';
import { createStateKey } from './utils';
import { stringifyOpenAPI } from './stringifyOpenAPI';
import { OpenAPITabs, OpenAPITabsList, OpenAPITabsPanels } from './OpenAPITabs';
import { checkIsReference } from './utils';
/**
 * Display code samples to execute the operation.
 * It supports the Redocly custom syntax as well (https://redocly.com/docs/api-reference-docs/specification-extensions/x-code-samples/)
 */
export function OpenAPICodeSample(props) {
    var _a;
    var data = props.data, context = props.context;
    var searchParams = new URLSearchParams();
    var headersObject = {};
    (_a = data.operation.parameters) === null || _a === void 0 ? void 0 : _a.forEach(function (param) {
        if (!param) {
            return;
        }
        if (param.in === 'header' && param.required) {
            var example = param.schema ? generateSchemaExample(param.schema) : undefined;
            if (example !== undefined && param.name) {
                headersObject[param.name] =
                    typeof example !== 'string' ? stringifyOpenAPI(example) : example;
            }
        }
        else if (param.in === 'query' && param.required) {
            var example = param.schema ? generateSchemaExample(param.schema) : undefined;
            if (example !== undefined && param.name) {
                searchParams.append(param.name, String(Array.isArray(example) ? example[0] : example));
            }
        }
    });
    var requestBody = !checkIsReference(data.operation.requestBody)
        ? data.operation.requestBody
        : undefined;
    var requestBodyContentEntries = (requestBody === null || requestBody === void 0 ? void 0 : requestBody.content)
        ? Object.entries(requestBody.content)
        : undefined;
    var requestBodyContent = requestBodyContentEntries === null || requestBodyContentEntries === void 0 ? void 0 : requestBodyContentEntries[0];
    var input = {
        url: getServersURL(data.servers) +
            data.path +
            (searchParams.size ? "?".concat(searchParams.toString()) : ''),
        method: data.method,
        body: requestBodyContent
            ? generateMediaTypeExample(requestBodyContent[1], { onlyRequired: true })
            : undefined,
        headers: __assign(__assign(__assign({}, getSecurityHeaders(data.securities)), headersObject), (requestBodyContent
            ? {
                'Content-Type': requestBodyContent[0],
            }
            : undefined)),
    };
    var autoCodeSamples = codeSampleGenerators.map(function (generator) { return ({
        key: "default-".concat(generator.id),
        label: generator.label,
        body: <context.CodeBlock code={generator.generate(input)} syntax={generator.syntax}/>,
    }); });
    // Use custom samples if defined
    var customCodeSamples = null;
    ['x-custom-examples', 'x-code-samples', 'x-codeSamples'].forEach(function (key) {
        var customSamples = data.operation[key];
        if (customSamples && Array.isArray(customSamples)) {
            customCodeSamples = customSamples
                .filter(function (sample) {
                return (typeof sample.label === 'string' &&
                    typeof sample.source === 'string' &&
                    typeof sample.lang === 'string');
            })
                .map(function (sample) { return ({
                key: "redocly-".concat(sample.lang),
                label: sample.label,
                body: <context.CodeBlock code={sample.source} syntax={sample.lang}/>,
            }); });
        }
    });
    // Code samples can be disabled at the top-level or at the operation level
    // If code samples are defined at the operation level, it will override the top-level setting
    var codeSamplesDisabled = data['x-codeSamples'] === false || data.operation['x-codeSamples'] === false;
    var samples = customCodeSamples !== null && customCodeSamples !== void 0 ? customCodeSamples : (!codeSamplesDisabled ? autoCodeSamples : []);
    if (samples.length === 0) {
        return null;
    }
    return (<OpenAPITabs stateKey={createStateKey('codesample')} items={samples}>
            <InteractiveSection header={<OpenAPITabsList />} className="openapi-codesample">
                <OpenAPITabsPanels />
            </InteractiveSection>
        </OpenAPITabs>);
}
function getSecurityHeaders(securities) {
    var _a;
    var _b, _c;
    var security = securities[0];
    if (!security) {
        return {};
    }
    switch (security[1].type) {
        case 'http': {
            var scheme = security[1].scheme;
            var format = (_b = security[1].bearerFormat) !== null && _b !== void 0 ? _b : 'YOUR_SECRET_TOKEN';
            if (scheme === null || scheme === void 0 ? void 0 : scheme.includes('bearer')) {
                scheme = 'Bearer';
            }
            else if (scheme === null || scheme === void 0 ? void 0 : scheme.includes('basic')) {
                scheme = 'Basic';
                format = 'username:password';
            }
            else if (scheme === null || scheme === void 0 ? void 0 : scheme.includes('token')) {
                scheme = 'Token';
            }
            return {
                Authorization: scheme + ' ' + format,
            };
        }
        case 'apiKey': {
            if (security[1].in !== 'header')
                return {};
            var name_1 = (_c = security[1].name) !== null && _c !== void 0 ? _c : 'Authorization';
            return _a = {},
                _a[name_1] = 'YOUR_API_KEY',
                _a;
        }
        default: {
            return {};
        }
    }
}
