import { useRef } from 'react';
import { mergeProps, useButton, useDisclosure, useFocusRing } from 'react-aria';
import { useDisclosureState } from 'react-stately';
/**
 * Display an interactive OpenAPI disclosure.
 * The label is optional and defaults to "child attributes".
 */
export function OpenAPIDisclosure(_a) {
    var context = _a.context, children = _a.children, label = _a.label;
    var state = useDisclosureState({});
    var panelRef = useRef(null);
    var triggerRef = useRef(null);
    var _b = useDisclosure({}, state, panelRef), triggerProps = _b.buttonProps, panelProps = _b.panelProps;
    var buttonProps = useButton(triggerProps, triggerRef).buttonProps;
    var _c = useFocusRing(), isFocusVisible = _c.isFocusVisible, focusProps = _c.focusProps;
    return (<div className="openapi-disclosure">
            <button ref={triggerRef} {...mergeProps(buttonProps, focusProps)} slot="trigger" className="openapi-disclosure-trigger" style={{
            outline: isFocusVisible
                ? '2px solid rgb(var(--primary-color-500) / 0.4)'
                : 'none',
        }}>
                {context.icons.plus}
                <span>
                    {"".concat(state.isExpanded ? 'Hide' : 'Show', " ").concat(label ? label : "child attributes")}
                </span>
            </button>

            {state.isExpanded && (<div ref={panelRef} {...panelProps} className="openapi-disclosure-panel">
                    {children}
                </div>)}
        </div>);
}
