import clsx from 'clsx';
import { Markdown } from './Markdown';
import { OpenAPICodeSample } from './OpenAPICodeSample';
import { OpenAPIResponseExample } from './OpenAPIResponseExample';
import { OpenAPISpec } from './OpenAPISpec';
import { OpenAPIPath } from './OpenAPIPath';
import { resolveDescription } from './utils';
/**
 * Display an interactive OpenAPI operation.
 */
export function OpenAPIOperation(props) {
    var _a;
    var className = props.className, data = props.data, context = props.context;
    var operation = data.operation;
    var clientContext = {
        defaultInteractiveOpened: context.defaultInteractiveOpened,
        icons: context.icons,
        blockKey: context.blockKey,
    };
    var description = (_a = resolveDescription(operation)) === null || _a === void 0 ? void 0 : _a.trim();
    return (<div className={clsx('openapi-operation', className)}>
            <div className="openapi-summary" id={context.id}>
                <h2 className="openapi-summary-title" data-deprecated={operation.deprecated}>
                    {operation.summary}
                </h2>
                {operation.deprecated && <div className="openapi-deprecated">Deprecated</div>}
            </div>
            <div className="openapi-columns">
                <div className="openapi-column-spec">
                    {operation['x-deprecated-sunset'] ? (<div className="openapi-deprecated-sunset openapi-description openapi-markdown">
                            This operation is deprecated and will be sunset on{' '}
                            <span className="openapi-deprecated-sunset-date">
                                {operation['x-deprecated-sunset']}
                            </span>
                            {"."}
                        </div>) : null}
                    {description ? (<div className="openapi-intro">
                            <Markdown className="openapi-description" source={description}/>
                        </div>) : null}
                    <OpenAPIPath data={data} context={context}/>
                    <OpenAPISpec data={data} context={clientContext}/>
                </div>
                <div className="openapi-column-preview">
                    <div className="openapi-column-preview-body">
                        <OpenAPICodeSample {...props}/>
                        <OpenAPIResponseExample {...props}/>
                    </div>
                </div>
            </div>
        </div>);
}
