import { generateSchemaExample } from './generateSchemaExample';
import { checkIsReference, createStateKey, resolveDescription } from './utils';
import { stringifyOpenAPI } from './stringifyOpenAPI';
import { OpenAPITabs, OpenAPITabsList, OpenAPITabsPanels } from './OpenAPITabs';
import { InteractiveSection } from './InteractiveSection';
/**
 * Display an example of the response content.
 */
export function OpenAPIResponseExample(props) {
    var data = props.data, context = props.context;
    // if there are no responses defined for the operation
    if (!data.operation.responses) {
        return null;
    }
    var responses = Object.entries(data.operation.responses);
    // Sort response to get 200, and 2xx first
    responses.sort(function (_a, _b) {
        var a = _a[0];
        var b = _b[0];
        if (a === 'default') {
            return 1;
        }
        if (b === 'default') {
            return -1;
        }
        if (a === '200') {
            return -1;
        }
        if (b === '200') {
            return 1;
        }
        return Number(a) - Number(b);
    });
    var examples = responses
        .map(function (_a) {
        var key = _a[0], value = _a[1];
        var responseObject = value;
        var mediaTypeObject = (function () {
            var _a;
            if (!responseObject.content) {
                return null;
            }
            var key = Object.keys(responseObject.content)[0];
            return ((_a = responseObject.content['application/json']) !== null && _a !== void 0 ? _a : (key ? responseObject.content[key] : null));
        })();
        if (!mediaTypeObject) {
            return {
                key: key,
                label: key,
                description: resolveDescription(responseObject),
                body: <OpenAPIEmptyResponseExample />,
            };
        }
        var example = handleUnresolvedReference((function () {
            var examples = mediaTypeObject.examples, example = mediaTypeObject.example;
            if (examples) {
                var key_1 = Object.keys(examples)[0];
                if (key_1) {
                    // @TODO handle multiple examples
                    var firstExample = examples[key_1];
                    if (firstExample) {
                        return firstExample;
                    }
                }
            }
            if (example) {
                return { value: example };
            }
            var schema = mediaTypeObject.schema;
            if (!schema) {
                return null;
            }
            return { value: generateSchemaExample(schema) };
        })());
        return {
            key: key,
            label: key,
            description: resolveDescription(responseObject),
            body: (example === null || example === void 0 ? void 0 : example.value) ? (<context.CodeBlock code={typeof example.value === 'string'
                    ? example.value
                    : stringifyOpenAPI(example.value, null, 2)} syntax="json"/>) : (<OpenAPIEmptyResponseExample />),
        };
    })
        .filter(function (val) {
        return Boolean(val);
    });
    if (examples.length === 0) {
        return null;
    }
    return (<OpenAPITabs stateKey={createStateKey('response-example')} items={examples}>
            <InteractiveSection header={<OpenAPITabsList />} className="openapi-response-example">
                <OpenAPITabsPanels />
            </InteractiveSection>
        </OpenAPITabs>);
}
function OpenAPIEmptyResponseExample() {
    return (<pre className="openapi-response-example-empty">
            <p>No body</p>
        </pre>);
}
function handleUnresolvedReference(input) {
    var isReference = checkIsReference(input === null || input === void 0 ? void 0 : input.value);
    if (isReference) {
        // If we find a reference that wasn't resolved or needed to be resolved externally, render out the URL
        return { value: input.value.$ref };
    }
    return input;
}
