import type { OpenAPIV3 } from '@gitbook/openapi-parser';
import type { OpenAPIClientContext } from './types';
type CircularRefsIds = Map<OpenAPIV3.SchemaObject, string>;
export interface OpenAPISchemaPropertyEntry {
    propertyName?: string;
    required?: boolean;
    schema: OpenAPIV3.SchemaObject;
}
/**
 * Render a property of an OpenAPI schema.
 */
export declare function OpenAPISchemaProperty(props: OpenAPISchemaPropertyEntry & {
    /** Set of objects already observed as parents */
    circularRefs?: CircularRefsIds;
    context: OpenAPIClientContext;
    className?: string;
}): import("react").JSX.Element;
/**
 * Render a set of properties of an OpenAPI schema.
 */
export declare function OpenAPISchemaProperties(props: {
    id?: string;
    properties: OpenAPISchemaPropertyEntry[];
    circularRefs?: CircularRefsIds;
    context: OpenAPIClientContext;
}): import("react").JSX.Element | null;
/**
 * Render a root schema (such as the request body or response body).
 */
export declare function OpenAPIRootSchema(props: {
    schema: OpenAPIV3.SchemaObject;
    context: OpenAPIClientContext;
}): import("react").JSX.Element;
/**
 * Render the enum value for a schema.
 */
export declare function OpenAPISchemaEnum(props: {
    enumValues: any[];
}): import("react").JSX.Element;
export declare function OpenAPISchemaPresentation(props: OpenAPISchemaPropertyEntry): import("react").JSX.Element;
/**
 * Get the alternatives to display for a schema.
 */
export declare function getSchemaAlternatives(schema: OpenAPIV3.SchemaObject, ancestors?: Set<OpenAPIV3.SchemaObject>): null | [OpenAPIV3.SchemaObject[], OpenAPIV3.DiscriminatorObject | undefined];
export declare function getSchemaTitle(schema: OpenAPIV3.SchemaObject, 
/** If the title is inferred in a oneOf with discriminator, we can use it to optimize the title */
discriminator?: OpenAPIV3.DiscriminatorObject): string;
export {};
