import { OpenAPIServerURLVariable } from './OpenAPIServerURLVariable';
/**
 * Show the url of the server with variables replaced by their default values.
 */
export function OpenAPIServerURL(props) {
    var _a;
    var servers = props.servers;
    var server = servers[0];
    if (!server) {
        return null;
    }
    var parts = parseServerURL((_a = server === null || server === void 0 ? void 0 : server.url) !== null && _a !== void 0 ? _a : '');
    return (<span>
            {parts.map(function (part, i) {
            var _a;
            if (part.kind === 'text') {
                return <span key={i}>{part.text}</span>;
            }
            else {
                var variable = (_a = server.variables) === null || _a === void 0 ? void 0 : _a[part.name];
                if (!variable) {
                    return <span key={i}>{"{".concat(part.name, "}")}</span>;
                }
                return (<OpenAPIServerURLVariable key={i} name={part.name} variable={variable}/>);
            }
        })}
        </span>);
}
/**
 * Get the default URL for the server.
 */
export function getServersURL(servers) {
    var _a;
    var server = servers[0];
    if (!server) {
        return '';
    }
    var parts = parseServerURL((_a = server === null || server === void 0 ? void 0 : server.url) !== null && _a !== void 0 ? _a : '');
    return parts
        .map(function (part) {
        var _a, _b, _c;
        if (part.kind === 'text') {
            return part.text;
        }
        else {
            return (_c = (_b = (_a = server.variables) === null || _a === void 0 ? void 0 : _a[part.name]) === null || _b === void 0 ? void 0 : _b.default) !== null && _c !== void 0 ? _c : "{".concat(part.name, "}");
        }
    })
        .join('');
}
function parseServerURL(url) {
    var parts = url.split(/{([^}]+)}/g);
    var result = [];
    for (var i = 0; i < parts.length; i++) {
        var part = parts[i];
        if (!part) {
            continue;
        }
        if (i % 2 === 0) {
            result.push({ kind: 'text', text: part });
        }
        else {
            result.push({ kind: 'variable', name: part });
        }
    }
    return result;
}
