import { getExampleFromSchema } from '@scalar/oas-utils/spec-getters';
/**
 * Generate a JSON example from a schema
 */
export function generateSchemaExample(schema, options) {
    if (options === void 0) { options = {}; }
    return getExampleFromSchema(schema, {
        emptyString: 'text',
        omitEmptyAndOptionalProperties: options.onlyRequired,
        variables: {
            'date-time': new Date().toISOString(),
            date: new Date().toISOString().split('T')[0],
            email: 'name@gmail.com',
            hostname: 'example.com',
            ipv4: '0.0.0.0',
            ipv6: '2001:0db8:85a3:0000:0000:8a2e:0370:7334',
            uri: 'https://example.com',
            uuid: '123e4567-e89b-12d3-a456-426614174000',
            binary: 'binary',
            byte: 'Ynl0ZXM=',
            password: 'password',
        },
    });
}
/**
 * Generate an example for a media type.
 */
export function generateMediaTypeExample(mediaType, options) {
    if (options === void 0) { options = {}; }
    if (mediaType.example) {
        return mediaType.example;
    }
    if (mediaType.examples) {
        var key = Object.keys(mediaType.examples)[0];
        if (key) {
            var example = mediaType.examples[key];
            if (example) {
                return example.value;
            }
        }
    }
    if (mediaType.schema) {
        return generateSchemaExample(mediaType.schema, options);
    }
    return undefined;
}
